@@ -46,9 +46,7 @@ class QTimeEdit;
 class QButtonGroup;
 class QGroupBox;
 
-namespace KPIM
-{
-
+namespace KPIM {
 /**
   @short Base class for GUI control elements used by @ref KPrefsDialog.
   @author Cornelius Schumacher
@@ -108,10 +106,10 @@ public:
     */
     QCheckBox *checkBox();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
-    QList<QWidget *> widgets() const Q_DECL_OVERRIDE;
+    QList<QWidget *> widgets() const override;
 
 private:
     KConfigSkeleton::ItemBool *mItem;
@@ -149,10 +147,10 @@ public:
     */
     QSpinBox *spinBox();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
-    QList<QWidget *> widgets() const Q_DECL_OVERRIDE;
+    QList<QWidget *> widgets() const override;
 
 private:
     KConfigSkeleton::ItemInt *mItem;
@@ -190,8 +188,8 @@ public:
     */
     KTimeComboBox *timeEdit();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
 private:
     KConfigSkeleton::ItemDateTime *mItem;
@@ -230,8 +228,8 @@ public:
     */
     QTimeEdit *timeEdit();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
 private:
     KConfigSkeleton::ItemDateTime *mItem;
@@ -269,8 +267,8 @@ public:
     */
     KDateComboBox *dateEdit();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
 private:
     KConfigSkeleton::ItemDateTime *mItem;
@@ -313,8 +311,8 @@ public:
     */
     KColorButton *button();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
 private:
     KConfigSkeleton::ItemColor *mItem;
@@ -341,8 +339,7 @@ public:
       @param parent  Parent widget.
       @param sampleText Sample text for previewing the selected font.
     */
-    explicit KPrefsWidFont(KConfigSkeleton::ItemFont *item,
-                           QWidget *parent = nullptr, const QString &sampleText = QString());
+    explicit KPrefsWidFont(KConfigSkeleton::ItemFont *item, QWidget *parent = nullptr, const QString &sampleText = QString());
     /**
       Destruct font setting widget.
     */
@@ -363,8 +360,8 @@ public:
     */
     QPushButton *button();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
 protected Q_SLOTS:
     void selectFont();
@@ -410,20 +407,17 @@ public:
       @param toolTip ToolTip help for the button.
       @param whatsThis What's This help for the button.
     */
-    void addRadio(int value,
-                  const QString &text,
-                  const QString &toolTip = QString(),
-                  const QString &whatsThis = QString());
+    void addRadio(int value, const QString &text, const QString &toolTip = QString(), const QString &whatsThis = QString());
 
     /**
       Return the box widget used by this widget.
     */
     QGroupBox *groupBox() const;
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
-    QList<QWidget *> widgets() const Q_DECL_OVERRIDE;
+    QList<QWidget *> widgets() const override;
 
 private:
     KConfigSkeleton::ItemEnum *mItem;
@@ -456,12 +450,12 @@ public:
     explicit KPrefsWidCombo(KConfigSkeleton::ItemEnum *item, QWidget *parent);
     virtual ~KPrefsWidCombo();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
     KComboBox *comboBox();
 
-    QList<QWidget *> widgets() const Q_DECL_OVERRIDE;
+    QList<QWidget *> widgets() const override;
     /**
       Return QLabel used by this control element.
     */
@@ -492,9 +486,7 @@ public:
       @param parent  Parent widget.
       @param echomode  Describes how a line edit should display its contents.
     */
-    explicit KPrefsWidString(KConfigSkeleton::ItemString *item,
-                             QWidget *parent = nullptr,
-                             KLineEdit::EchoMode echomode = KLineEdit::Normal);
+    explicit KPrefsWidString(KConfigSkeleton::ItemString *item, QWidget *parent = nullptr, KLineEdit::EchoMode echomode = KLineEdit::Normal);
     /**
       Destructor.
     */
@@ -509,10 +501,10 @@ public:
     */
     KLineEdit *lineEdit();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
-    QList<QWidget *> widgets() const Q_DECL_OVERRIDE;
+    QList<QWidget *> widgets() const override;
 
 private:
     KConfigSkeleton::ItemString *mItem;
@@ -541,10 +533,7 @@ public:
       @param filter URLRequester filter
       @param mode  Describes how a line edit should display its contents.
     */
-    explicit KPrefsWidPath(KConfigSkeleton::ItemPath *item,
-                           QWidget *parent = nullptr,
-                           const QString &filter = QString(),
-                           KFile::Modes = KFile::File);
+    explicit KPrefsWidPath(KConfigSkeleton::ItemPath *item, QWidget *parent = nullptr, const QString &filter = QString(), KFile::Modes = KFile::File);
 
     /**
       Destructor.
@@ -561,10 +550,10 @@ public:
     */
     KUrlRequester *urlRequester();
 
-    void readConfig() Q_DECL_OVERRIDE;
-    void writeConfig() Q_DECL_OVERRIDE;
+    void readConfig() override;
+    void writeConfig() override;
 
-    QList<QWidget *> widgets() const Q_DECL_OVERRIDE;
+    QList<QWidget *> widgets() const override;
 
 private:
     KConfigSkeleton::ItemPath *mItem;
@@ -612,8 +601,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidBool *addWidBool(KConfigSkeleton::ItemBool *item,
-                              QWidget *parent = nullptr);
+    KPrefsWidBool *addWidBool(KConfigSkeleton::ItemBool *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidInt object.
@@ -621,8 +609,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidInt *addWidInt(KConfigSkeleton::ItemInt *item,
-                            QWidget *parent = nullptr);
+    KPrefsWidInt *addWidInt(KConfigSkeleton::ItemInt *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidDate object.
@@ -630,8 +617,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidDate *addWidDate(KConfigSkeleton::ItemDateTime *item,
-                              QWidget *parent = nullptr);
+    KPrefsWidDate *addWidDate(KConfigSkeleton::ItemDateTime *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidTime object.
@@ -639,8 +625,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidTime *addWidTime(KConfigSkeleton::ItemDateTime *item,
-                              QWidget *parent = nullptr);
+    KPrefsWidTime *addWidTime(KConfigSkeleton::ItemDateTime *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidDuration object.
@@ -649,9 +634,7 @@ public:
       @param format  display format. default is "hh:mm:ss"
       @param parent  Parent widget.
     */
-    KPrefsWidDuration *addWidDuration(KConfigSkeleton::ItemDateTime *item,
-                                      const QString &format,
-                                      QWidget *parent = nullptr);
+    KPrefsWidDuration *addWidDuration(KConfigSkeleton::ItemDateTime *item, const QString &format, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidColor object.
@@ -659,8 +642,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidColor *addWidColor(KConfigSkeleton::ItemColor *item,
-                                QWidget *parent = nullptr);
+    KPrefsWidColor *addWidColor(KConfigSkeleton::ItemColor *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidRadios object. The choices represented by the
@@ -669,8 +651,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidRadios *addWidRadios(KConfigSkeleton::ItemEnum *item,
-                                  QWidget *parent = nullptr);
+    KPrefsWidRadios *addWidRadios(KConfigSkeleton::ItemEnum *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidCombo object. The choices represented by the
@@ -679,8 +660,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidCombo *addWidCombo(KConfigSkeleton::ItemEnum *item,
-                                QWidget *parent = nullptr);
+    KPrefsWidCombo *addWidCombo(KConfigSkeleton::ItemEnum *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidString object.
@@ -688,8 +668,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidString *addWidString(KConfigSkeleton::ItemString *item,
-                                  QWidget *parent = nullptr);
+    KPrefsWidString *addWidString(KConfigSkeleton::ItemString *item, QWidget *parent = nullptr);
 
     /**
       Register a path @ref KPrefsWidPath object.
@@ -699,10 +678,7 @@ public:
       @param filter URLRequester filter
       @param mode URLRequester mode
     */
-    KPrefsWidPath *addWidPath(KConfigSkeleton::ItemPath *item,
-                              QWidget *parent = nullptr,
-                              const QString &filter = QString(),
-                              KFile::Modes mode = KFile::File);
+    KPrefsWidPath *addWidPath(KConfigSkeleton::ItemPath *item, QWidget *parent = nullptr, const QString &filter = QString(), KFile::Modes mode = KFile::File);
 
     /**
       Register a password @ref KPrefsWidString object, with echomode set to KLineEdit::Password.
@@ -710,8 +686,7 @@ public:
       @param item    The KConfigSkeletonItem representing the preferences entry.
       @param parent  Parent widget.
     */
-    KPrefsWidString *addWidPassword(KConfigSkeleton::ItemString *item,
-                                    QWidget *parent = nullptr);
+    KPrefsWidString *addWidPassword(KConfigSkeleton::ItemString *item, QWidget *parent = nullptr);
 
     /**
       Register a @ref KPrefsWidFont object.
@@ -721,9 +696,7 @@ public:
       @param parent     Parent widget.
       @param sampleText Sample text for previewing the selected font.
     */
-    KPrefsWidFont *addWidFont(KConfigSkeleton::ItemFont *item,
-                              QWidget *parent = nullptr,
-                              const QString &sampleText = QString());
+    KPrefsWidFont *addWidFont(KConfigSkeleton::ItemFont *item, QWidget *parent = nullptr, const QString &sampleText = QString());
 
     /** Set all widgets to default values. */
     void setWidDefaults();
@@ -764,8 +737,7 @@ public:
       @param name   Widget name.
       @param modal  true, if dialog has to be modal, false for non-modal.
     */
-    explicit KPrefsDialog(KConfigSkeleton *prefs, QWidget *parent = nullptr,
-                          bool modal = false);
+    explicit KPrefsDialog(KConfigSkeleton *prefs, QWidget *parent = nullptr, bool modal = false);
 
     /**
       Destructor.
@@ -800,34 +772,42 @@ protected Q_SLOTS:
 
 protected:
     /** Implement this to read custom configuration widgets. */
-    virtual void usrReadConfig() {}
+    virtual void usrReadConfig()
+    {
+    }
+
     /** Implement this to write custom configuration widgets. */
-    virtual void usrWriteConfig() {}
+    virtual void usrWriteConfig()
+    {
+    }
 };
 
 class KDEPIM_EXPORT KPrefsModule : public KCModule, public KPrefsWidManager
 {
     Q_OBJECT
 public:
-    KPrefsModule(KConfigSkeleton *,
-                 QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+    KPrefsModule(KConfigSkeleton *, QWidget *parent = nullptr, const QVariantList &args = QVariantList());
 
-    void addWid(KPrefsWid *) Q_DECL_OVERRIDE;
+    void addWid(KPrefsWid *) override;
 
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
 public Q_SLOTS:
     void slotWidChanged();
 
 protected:
     /** Implement this to read custom configuration widgets. */
-    virtual void usrReadConfig() {}
-    /** Implement this to write custom configuration widgets. */
-    virtual void usrWriteConfig() {}
-};
+    virtual void usrReadConfig()
+    {
+    }
 
+    /** Implement this to write custom configuration widgets. */
+    virtual void usrWriteConfig()
+    {
+    }
+};
 }
 
 #endif
